# Ollama-GUI

![GitHub License](https://img.shields.io/github/license/chyok/ollama-gui)
![PyPI - Version](https://img.shields.io/pypi/v/ollama-gui)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/ollama-gui)

A very simple ollama GUI, implemented using the built-in Python Tkinter library, with no additional dependencies.
Provide you with the simplest possible visual Ollama interface.

![ollama-gui-1-0-3](https://github.com/chyok/ollama-gui/assets/32629225/4a733a19-3201-4440-b6d5-eddd62294a0b)

+ one file project.
+ no external dependencies.

## Before Start
We need to set up llama service first.

Please refer to: [Ollama](https://ollama.com/)


## Run

Choose any way you like:

### source code
`python ollama_gui.py`

### using pip

```
pip install ollama-gui
ollama-gui
```

### binary file

| Platform | Download Link                                                                                          | 
|----------|--------------------------------------------------------------------------------------------------------|
| Windows  | [Download](https://github.com/chyok/ollama-gui/releases) |

## License

This project is licensed under the [MIT License](LICENSE).

